/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.model;

import java.io.Serializable;
import java.util.Objects;

/**
 * composite key for the first two fields of an AgroURI.
 * 
 * @author johan
 */
public class FarmID implements Serializable, EnterpriseIdProvider {
    private static final long serialVersionUID = 1L;
    private final IssuingAgency agency;
    private final String id;

    public FarmID(EnterpriseIdProvider eip) {
        this.agency = eip.getIssuingAgency();
        this.id = eip.getEnterpriseId();
    }
    
    @Override
    public IssuingAgency getIssuingAgency() {
        return agency;
    }

    @Override
    public String getEnterpriseId() {
        return id;
    }

    @Override
    public int hashCode() {
        int hash = 5;
        hash = 53 * hash + (this.agency != null ? this.agency.hashCode() : 0);
        hash = 53 * hash + Objects.hashCode(this.id);
        return hash;
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final FarmID other = (FarmID) obj;
        if (this.agency != other.agency) {
            return false;
        }
        if (!Objects.equals(this.id, other.id)) {
            return false;
        }
        return true;
    }

    @Override
    public String toString() {
        return "FarmID{" + "agency=" + agency + ", id=" + id + '}';
    }
    
}
