/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.model;

/**
 *
 * @author johan
 */
public enum ItemIdType {
    // EDI-Teelt++ ItemIdTypes:

    FRM, FLD, CFD, AFD, OPR, TZN, ALL, PRT,
    // ISOXML:
    TSK,
    // Agrosense entities not (yet) in any specification:
    CPU, VCE, IMT,
    //TODO: fieldplan; 
    CRP, CLN, VTY, CTN,
    //Tasks
    FTK, STK,
    //Sensor Run
    SRU;

    /**
     * This method can be used to fetch the ItemIdType for a specific class. It
     * uses the simple name of the class passed as parameter in a switch
     * statement to return the correct ItemIdType.
     *
     * @param clazz Class that you wish to receive the ItemIdType for
     * @return ItemTypeId for the class passed as parameter OR null if no
     * ItemIdType could be found for the class. Not all classes are entities
     * with defined ItemIdTypes!
     */
    public static ItemIdType fromClass(Class clazz) {
        String className = clazz.getSimpleName();
        switch (className) {
            case "Field":
                return FLD;
            case "Farm":
                return FRM;
            case "CropField":
                return CFD;
            case "ActivityField":
                return AFD;
            case "TreatmentZone":
                return TZN;
            case "Vehicle":
                return VCE;
            case "Implement":
                return IMT;
            case "CropDefinition":
                return CTN;
            case "Crop":
                return CRP;
            case "Classification":
                return CLN;
            case "SensorRun":
                return SRU;                
            case "Variety":
                return VTY;
            case "FieldTask":
                return FTK;
            case "SprayTask":
                return STK;
            default:
                return null;
        }
    }
}
